@@ -33,6 +33,7 @@ ProtocolD::ProtocolD(int sock,QObject *parent)
   int flags;
 
   proto_socket=NULL;
+  proto_tether_subscribed=false;
   proto_destinations_subscribed=false;
   proto_gpis_subscribed=false;
   proto_gpos_subscribed=false;
@@ -138,6 +139,19 @@ void ProtocolD::disconnectedData()
 }
 
 
+void ProtocolD::tetherStateUpdated(bool state)
+{
+  if(proto_tether_subscribed) {
+    if(state) {
+      proto_socket->write("TETHER\tY\r\n");
+    }
+    else {
+      proto_socket->write("TETHER\tN\r\n");
+    }
+  }
+}
+
+
 void ProtocolD::nodeAdded(const QHostAddress &host_addr)
 {
   QString sql;
@@ -589,6 +603,31 @@ void ProtocolD::ProcessCommand(const QString &cmd)
     return;
   }
 
+  if(keyword=="listtether") {
+    sql=QString("select IS_ACTIVE from TETHER");
+    q=new QSqlQuery(sql);
+    if(q->first()) {
+      proto_socket->
+	write((QString("TETHER\t")+q->value(0).toString()+"\r\n").toUtf8());
+    }
+    delete q;
+    proto_socket->write("ok\r\n");
+    return;
+  }
+
+  if(keyword=="subscribetether") {
+    proto_tether_subscribed=true;
+    sql=QString("select IS_ACTIVE from TETHER");
+    q=new QSqlQuery(sql);
+    if(q->first()) {
+      proto_socket->
+	write((QString("TETHER\t")+q->value(0).toString()+"\r\n").toUtf8());
+    }
+    delete q;
+    proto_socket->write("ok\r\n");
+    return;
+  }
+
   if((keyword=="setcrosspoint")&&(cmds.size()==5)) {
     bool ok;
 
